@@ -22,6 +22,7 @@ class LogQSClient:
         api_key_secret=None,
         pretty=None,
         verbose=None,
+        dry_run=None,
     ):
         self._env_config = {**dotenv_values(".env"), **os.environ}
 
@@ -56,12 +57,19 @@ class LogQSClient:
         if self._verbose:
             logger.setLevel(logging.DEBUG)
 
+        self._dry_run = (
+            dry_run
+            if dry_run
+            else bool(strtobool(self._env_config.get("LQS_DRY_RUN", "false")))
+        )
+
         self.config = {
             "api_url": self._api_url,
             "api_key_id": self._api_key_id,
             "api_key_secret": self._api_key_secret,
             "pretty": self._pretty,
             "verbose": self._verbose,
+            "dry_run": self._dry_run,
         }
 
         obf_key = self._api_key_secret[:4] + "*" * (len(self._api_key_secret) - 4)
